from setuptools import setup, find_packages

setup(
    name='VideoWiki-BigBlueButton',
    version='0.1',
    description='VideoWiki Conferencing BigBlueButton',
    packages=find_packages(),
    install_requires=[
        'api==0.0.7',
        'asgiref==3.6.0',
        'backports.zoneinfo==0.2.1',
        'bleach==6.0.0',
        'certifi==2022.12.7',
        'cffi==1.15.1',
        'charset-normalizer==3.1.0',
        'cryptography==40.0.1',
        'Django==4.1.7',
        'django-utils-six==2.0',
        'djangorestframework==3.14.0',
        'djangorestframework-simplejwt==3.0',
        'docutils==0.19',
        'idna==3.4',
        'importlib-metadata==6.1.0',
        'importlib-resources==5.12.0',
        'jaraco.classes==3.2.3',
        'jeepney==0.8.0',
        'keyring==23.13.1',
        'markdown-it-py==2.2.0',
        'mdurl==0.1.2',
        'more-itertools==9.1.0',
        'nose==1.3.7',
        'Pillow==9.4.0',
        'pkginfo==1.9.6',
        'pycparser==2.21',
        'Pygments==2.14.0',
        'PyJWT==2.6.0',
        'python-dotenv==1.0.0',
        'pytz==2023.2',
        'readme-renderer==37.3',
        'requests==2.28.2',
        'requests-toolbelt==0.10.1',
        'rest-framework-simplejwt==0.0.2',
        'rfc3986==2.0.0',
        'rich==13.3.3',
        'SecretStorage==3.3.3',
        'six==1.16.0',
        'sqlparse==0.4.3',
        'twine==4.0.2',
        'typing-extensions==4.5.0',
        'urllib3==1.26.15',
        'webencodings==0.5.1',
        'zipp==3.15.0'
    ],
)
